Skip to main content

pylint Score PyPI - Version GitHub Tag Python Version from PEP 621 TOML License

genpull

This creates a LaTeX file from the League of Comic Geeks export function. This LaTeX file will generate a PDF subscription list that can be sent to your local comic book shop. There are some stores that want both a connection to the League of Comic Geeks and a "paper" subscription list.

This is also useful for having a PDF on your phone to track your overall subscriptions. I've used this when I need to remember if a comic that's appeared in my pull is a recommendation or not.

Installation

Use pip to install this from PyPI.

pip install genpull

You can also run genpull using pipx. The command below runs genpull and shows all of the options.

pipx run genpull --help

How to Use genpull

Export a subscription list (in old Excel format) by going to League of Comic Geeks' Subscriptions page and selecting "Export Pulls" underneath the gear icon on the right side. Save that file which is referred to below as INFILENAME.

From the terminal, go to the directory that contains your saved INFILENAME file and run genpull using the command and format below. The simplest case is:

genpull --username "Your Name" --output "subscriptions.tex" INFILENAME

This will generate the LaTeX file and create the subscriptions.tex file. If you omit the output option this will print the generated file to the terminal. You can use a redirect if you prefer.

genpull --username "Your Name" INFILENAME > subscriptions.tex

Take this LaTeX file and typeset it twice to generate the PDF. It needs to be done twice because there are page numbers that appear.

genpull Format

Usage: genpull [OPTIONS] [INFILENAME]

Arguments

infilename      [INFILENAME]  The League of Comic Geeks Export Pulls xls filename. [default: Pulls-ComicGeeks.xls]

Options

--debug   --no-debug          Show debugging information. (lots of output) [default: no-debug]
--version --no-version        Shows the version of genpull [default: no-version]     
--output                TEXT  Name of LaTeX output file. [default: None]
--username              TEXT  Name of subscription list owner. [default: Nevins]
--install-completion          Install completion for the current shell.
--show-completion             Show completion for the current shell, to copy it or customize the installation.
--help                        Show this message and exit.        

Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

License

Apache License 2.0

Metadata

Release files for genpull 1.4

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for genpull 1.4
File Size Uploaded
genpull-1.4.tar.gz 11.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for genpull 1.4
File Interpreter ABI Platform
genpull-1.4-py3-none-any.whl Python 3 none any Details

Total release size: 22.1 kB

Release files / genpull-1.4.tar.gz

Download URL genpull-1.4.tar.gz
Size 11.0 kB
Tags Source
SHA-256 checksum
How to use checksums
db5b18dcf4b01f3db19b1d2f02d0d6494dee511c0c95c9ff793c0afe798a9031
BLAKE2b-256 checksum
How to use checksums
2db03a376db4877b88d18122b80ee28a23ca33b74a68e3a2f04ecba703a53109
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.13.2

Release files / genpull-1.4-py3-none-any.whl

Download URL genpull-1.4-py3-none-any.whl
Size 11.1 kB
Tags Python 3
SHA-256 checksum
How to use checksums
915743b11058ab63858b6e3639359c6cfe852370752fc3b3190bab4d3a637836
BLAKE2b-256 checksum
How to use checksums
628f5d6199df718443f8372d12e52425b97514e04045a60e3bfb08494e11facf
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/6.1.0 CPython/3.13.2

Release history Release notifications | RSS feed

This release

1.4 This release

2 release files

1.3

2 release files

1.2

2 release files

1.1

2 release files

1.0.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page